# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetGenaiKnowledgeBaseResult',
    'AwaitableGetGenaiKnowledgeBaseResult',
    'get_genai_knowledge_base',
    'get_genai_knowledge_base_output',
]

@pulumi.output_type
class GetGenaiKnowledgeBaseResult:
    """
    A collection of values returned by getGenaiKnowledgeBase.
    """
    def __init__(__self__, added_to_agent_at=None, created_at=None, database_id=None, embedding_model_uuid=None, id=None, is_public=None, last_indexing_jobs=None, name=None, project_id=None, region=None, tags=None, updated_at=None, user_id=None, uuid=None):
        if added_to_agent_at and not isinstance(added_to_agent_at, str):
            raise TypeError("Expected argument 'added_to_agent_at' to be a str")
        pulumi.set(__self__, "added_to_agent_at", added_to_agent_at)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if database_id and not isinstance(database_id, str):
            raise TypeError("Expected argument 'database_id' to be a str")
        pulumi.set(__self__, "database_id", database_id)
        if embedding_model_uuid and not isinstance(embedding_model_uuid, str):
            raise TypeError("Expected argument 'embedding_model_uuid' to be a str")
        pulumi.set(__self__, "embedding_model_uuid", embedding_model_uuid)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_public and not isinstance(is_public, bool):
            raise TypeError("Expected argument 'is_public' to be a bool")
        pulumi.set(__self__, "is_public", is_public)
        if last_indexing_jobs and not isinstance(last_indexing_jobs, list):
            raise TypeError("Expected argument 'last_indexing_jobs' to be a list")
        pulumi.set(__self__, "last_indexing_jobs", last_indexing_jobs)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)
        if uuid and not isinstance(uuid, str):
            raise TypeError("Expected argument 'uuid' to be a str")
        pulumi.set(__self__, "uuid", uuid)

    @_builtins.property
    @pulumi.getter(name="addedToAgentAt")
    def added_to_agent_at(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "added_to_agent_at")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="databaseId")
    def database_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "database_id")

    @_builtins.property
    @pulumi.getter(name="embeddingModelUuid")
    def embedding_model_uuid(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "embedding_model_uuid")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isPublic")
    def is_public(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "is_public")

    @_builtins.property
    @pulumi.getter(name="lastIndexingJobs")
    def last_indexing_jobs(self) -> Optional[Sequence['outputs.GetGenaiKnowledgeBaseLastIndexingJobResult']]:
        return pulumi.get(self, "last_indexing_jobs")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[Sequence[_builtins.str]]:
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "user_id")

    @_builtins.property
    @pulumi.getter
    def uuid(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "uuid")


class AwaitableGetGenaiKnowledgeBaseResult(GetGenaiKnowledgeBaseResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGenaiKnowledgeBaseResult(
            added_to_agent_at=self.added_to_agent_at,
            created_at=self.created_at,
            database_id=self.database_id,
            embedding_model_uuid=self.embedding_model_uuid,
            id=self.id,
            is_public=self.is_public,
            last_indexing_jobs=self.last_indexing_jobs,
            name=self.name,
            project_id=self.project_id,
            region=self.region,
            tags=self.tags,
            updated_at=self.updated_at,
            user_id=self.user_id,
            uuid=self.uuid)


def get_genai_knowledge_base(added_to_agent_at: Optional[_builtins.str] = None,
                             database_id: Optional[_builtins.str] = None,
                             embedding_model_uuid: Optional[_builtins.str] = None,
                             is_public: Optional[_builtins.bool] = None,
                             last_indexing_jobs: Optional[Sequence[Union['GetGenaiKnowledgeBaseLastIndexingJobArgs', 'GetGenaiKnowledgeBaseLastIndexingJobArgsDict']]] = None,
                             name: Optional[_builtins.str] = None,
                             project_id: Optional[_builtins.str] = None,
                             region: Optional[_builtins.str] = None,
                             tags: Optional[Sequence[_builtins.str]] = None,
                             user_id: Optional[_builtins.str] = None,
                             uuid: Optional[_builtins.str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGenaiKnowledgeBaseResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['addedToAgentAt'] = added_to_agent_at
    __args__['databaseId'] = database_id
    __args__['embeddingModelUuid'] = embedding_model_uuid
    __args__['isPublic'] = is_public
    __args__['lastIndexingJobs'] = last_indexing_jobs
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    __args__['tags'] = tags
    __args__['userId'] = user_id
    __args__['uuid'] = uuid
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('digitalocean:index/getGenaiKnowledgeBase:getGenaiKnowledgeBase', __args__, opts=opts, typ=GetGenaiKnowledgeBaseResult).value

    return AwaitableGetGenaiKnowledgeBaseResult(
        added_to_agent_at=pulumi.get(__ret__, 'added_to_agent_at'),
        created_at=pulumi.get(__ret__, 'created_at'),
        database_id=pulumi.get(__ret__, 'database_id'),
        embedding_model_uuid=pulumi.get(__ret__, 'embedding_model_uuid'),
        id=pulumi.get(__ret__, 'id'),
        is_public=pulumi.get(__ret__, 'is_public'),
        last_indexing_jobs=pulumi.get(__ret__, 'last_indexing_jobs'),
        name=pulumi.get(__ret__, 'name'),
        project_id=pulumi.get(__ret__, 'project_id'),
        region=pulumi.get(__ret__, 'region'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        user_id=pulumi.get(__ret__, 'user_id'),
        uuid=pulumi.get(__ret__, 'uuid'))
def get_genai_knowledge_base_output(added_to_agent_at: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                    database_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                    embedding_model_uuid: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                    is_public: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                                    last_indexing_jobs: Optional[pulumi.Input[Optional[Sequence[Union['GetGenaiKnowledgeBaseLastIndexingJobArgs', 'GetGenaiKnowledgeBaseLastIndexingJobArgsDict']]]]] = None,
                                    name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                    project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                    region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                    tags: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                                    user_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                    uuid: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGenaiKnowledgeBaseResult]:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['addedToAgentAt'] = added_to_agent_at
    __args__['databaseId'] = database_id
    __args__['embeddingModelUuid'] = embedding_model_uuid
    __args__['isPublic'] = is_public
    __args__['lastIndexingJobs'] = last_indexing_jobs
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    __args__['tags'] = tags
    __args__['userId'] = user_id
    __args__['uuid'] = uuid
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('digitalocean:index/getGenaiKnowledgeBase:getGenaiKnowledgeBase', __args__, opts=opts, typ=GetGenaiKnowledgeBaseResult)
    return __ret__.apply(lambda __response__: GetGenaiKnowledgeBaseResult(
        added_to_agent_at=pulumi.get(__response__, 'added_to_agent_at'),
        created_at=pulumi.get(__response__, 'created_at'),
        database_id=pulumi.get(__response__, 'database_id'),
        embedding_model_uuid=pulumi.get(__response__, 'embedding_model_uuid'),
        id=pulumi.get(__response__, 'id'),
        is_public=pulumi.get(__response__, 'is_public'),
        last_indexing_jobs=pulumi.get(__response__, 'last_indexing_jobs'),
        name=pulumi.get(__response__, 'name'),
        project_id=pulumi.get(__response__, 'project_id'),
        region=pulumi.get(__response__, 'region'),
        tags=pulumi.get(__response__, 'tags'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        user_id=pulumi.get(__response__, 'user_id'),
        uuid=pulumi.get(__response__, 'uuid')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['DatabaseRedisConfigArgs', 'DatabaseRedisConfig']

@pulumi.input_type
class DatabaseRedisConfigArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[_builtins.str],
                 acl_channels_default: Optional[pulumi.Input[_builtins.str]] = None,
                 io_threads: Optional[pulumi.Input[_builtins.int]] = None,
                 lfu_decay_time: Optional[pulumi.Input[_builtins.int]] = None,
                 lfu_log_factor: Optional[pulumi.Input[_builtins.int]] = None,
                 maxmemory_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 notify_keyspace_events: Optional[pulumi.Input[_builtins.str]] = None,
                 number_of_databases: Optional[pulumi.Input[_builtins.int]] = None,
                 persistence: Optional[pulumi.Input[_builtins.str]] = None,
                 pubsub_client_output_buffer_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 ssl: Optional[pulumi.Input[_builtins.bool]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a DatabaseRedisConfig resource.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the target Redis cluster.
        :param pulumi.Input[_builtins.str] acl_channels_default: Determines default pub/sub channels' ACL for new users if an ACL is not supplied. When this option is not defined, `allchannels` is assumed to keep backward compatibility. This option doesn't affect Redis' `acl-pubsub-default` configuration. Supported values are: `allchannels` and `resetchannels`
        :param pulumi.Input[_builtins.int] io_threads: The Redis IO thread count.
        :param pulumi.Input[_builtins.int] lfu_decay_time: The LFU maxmemory policy counter decay time in minutes.
        :param pulumi.Input[_builtins.int] lfu_log_factor: The counter logarithm factor for volatile-lfu and allkeys-lfu maxmemory policies.
        :param pulumi.Input[_builtins.str] maxmemory_policy: A string specifying the desired eviction policy for the Redis cluster.Supported values are: `noeviction`, `allkeys-lru`, `allkeys-random`, `volatile-lru`, `volatile-random`, `volatile-ttl`
        :param pulumi.Input[_builtins.str] notify_keyspace_events: The `notify-keyspace-events` option. Requires at least `K` or `E`.
        :param pulumi.Input[_builtins.int] number_of_databases: The number of Redis databases. Changing this will cause a restart of Redis service.
        :param pulumi.Input[_builtins.str] persistence: When persistence is `rdb`, Redis does RDB dumps each 10 minutes if any key is changed. Also RDB dumps are done according to backup schedule for backup purposes. When persistence is `off`, no RDB dumps and backups are done, so data can be lost at any moment if service is restarted for any reason, or if service is powered off. Also service can't be forked.
        :param pulumi.Input[_builtins.int] pubsub_client_output_buffer_limit: The output buffer limit for pub/sub clients in MB. The value is the hard limit, the soft limit is 1/4 of the hard limit. When setting the limit, be mindful of the available memory in the selected service plan.
        :param pulumi.Input[_builtins.bool] ssl: A boolean indicating whether to require SSL to access Redis.
               - When enabled, Redis accepts only SSL connections on port `25061`.
               - When disabled, port `25060` is opened for non-SSL connections, while port `25061` remains available for SSL connections.
        :param pulumi.Input[_builtins.int] timeout: The Redis idle connection timeout in seconds.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        if acl_channels_default is not None:
            pulumi.set(__self__, "acl_channels_default", acl_channels_default)
        if io_threads is not None:
            pulumi.set(__self__, "io_threads", io_threads)
        if lfu_decay_time is not None:
            pulumi.set(__self__, "lfu_decay_time", lfu_decay_time)
        if lfu_log_factor is not None:
            pulumi.set(__self__, "lfu_log_factor", lfu_log_factor)
        if maxmemory_policy is not None:
            pulumi.set(__self__, "maxmemory_policy", maxmemory_policy)
        if notify_keyspace_events is not None:
            pulumi.set(__self__, "notify_keyspace_events", notify_keyspace_events)
        if number_of_databases is not None:
            pulumi.set(__self__, "number_of_databases", number_of_databases)
        if persistence is not None:
            pulumi.set(__self__, "persistence", persistence)
        if pubsub_client_output_buffer_limit is not None:
            pulumi.set(__self__, "pubsub_client_output_buffer_limit", pubsub_client_output_buffer_limit)
        if ssl is not None:
            pulumi.set(__self__, "ssl", ssl)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the target Redis cluster.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter(name="aclChannelsDefault")
    def acl_channels_default(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determines default pub/sub channels' ACL for new users if an ACL is not supplied. When this option is not defined, `allchannels` is assumed to keep backward compatibility. This option doesn't affect Redis' `acl-pubsub-default` configuration. Supported values are: `allchannels` and `resetchannels`
        """
        return pulumi.get(self, "acl_channels_default")

    @acl_channels_default.setter
    def acl_channels_default(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "acl_channels_default", value)

    @_builtins.property
    @pulumi.getter(name="ioThreads")
    def io_threads(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The Redis IO thread count.
        """
        return pulumi.get(self, "io_threads")

    @io_threads.setter
    def io_threads(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "io_threads", value)

    @_builtins.property
    @pulumi.getter(name="lfuDecayTime")
    def lfu_decay_time(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The LFU maxmemory policy counter decay time in minutes.
        """
        return pulumi.get(self, "lfu_decay_time")

    @lfu_decay_time.setter
    def lfu_decay_time(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "lfu_decay_time", value)

    @_builtins.property
    @pulumi.getter(name="lfuLogFactor")
    def lfu_log_factor(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The counter logarithm factor for volatile-lfu and allkeys-lfu maxmemory policies.
        """
        return pulumi.get(self, "lfu_log_factor")

    @lfu_log_factor.setter
    def lfu_log_factor(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "lfu_log_factor", value)

    @_builtins.property
    @pulumi.getter(name="maxmemoryPolicy")
    def maxmemory_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A string specifying the desired eviction policy for the Redis cluster.Supported values are: `noeviction`, `allkeys-lru`, `allkeys-random`, `volatile-lru`, `volatile-random`, `volatile-ttl`
        """
        return pulumi.get(self, "maxmemory_policy")

    @maxmemory_policy.setter
    def maxmemory_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "maxmemory_policy", value)

    @_builtins.property
    @pulumi.getter(name="notifyKeyspaceEvents")
    def notify_keyspace_events(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The `notify-keyspace-events` option. Requires at least `K` or `E`.
        """
        return pulumi.get(self, "notify_keyspace_events")

    @notify_keyspace_events.setter
    def notify_keyspace_events(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "notify_keyspace_events", value)

    @_builtins.property
    @pulumi.getter(name="numberOfDatabases")
    def number_of_databases(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of Redis databases. Changing this will cause a restart of Redis service.
        """
        return pulumi.get(self, "number_of_databases")

    @number_of_databases.setter
    def number_of_databases(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "number_of_databases", value)

    @_builtins.property
    @pulumi.getter
    def persistence(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        When persistence is `rdb`, Redis does RDB dumps each 10 minutes if any key is changed. Also RDB dumps are done according to backup schedule for backup purposes. When persistence is `off`, no RDB dumps and backups are done, so data can be lost at any moment if service is restarted for any reason, or if service is powered off. Also service can't be forked.
        """
        return pulumi.get(self, "persistence")

    @persistence.setter
    def persistence(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "persistence", value)

    @_builtins.property
    @pulumi.getter(name="pubsubClientOutputBufferLimit")
    def pubsub_client_output_buffer_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The output buffer limit for pub/sub clients in MB. The value is the hard limit, the soft limit is 1/4 of the hard limit. When setting the limit, be mindful of the available memory in the selected service plan.
        """
        return pulumi.get(self, "pubsub_client_output_buffer_limit")

    @pubsub_client_output_buffer_limit.setter
    def pubsub_client_output_buffer_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "pubsub_client_output_buffer_limit", value)

    @_builtins.property
    @pulumi.getter
    def ssl(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        A boolean indicating whether to require SSL to access Redis.
        - When enabled, Redis accepts only SSL connections on port `25061`.
        - When disabled, port `25060` is opened for non-SSL connections, while port `25061` remains available for SSL connections.
        """
        return pulumi.get(self, "ssl")

    @ssl.setter
    def ssl(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "ssl", value)

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The Redis idle connection timeout in seconds.
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "timeout", value)


@pulumi.input_type
class _DatabaseRedisConfigState:
    def __init__(__self__, *,
                 acl_channels_default: Optional[pulumi.Input[_builtins.str]] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 io_threads: Optional[pulumi.Input[_builtins.int]] = None,
                 lfu_decay_time: Optional[pulumi.Input[_builtins.int]] = None,
                 lfu_log_factor: Optional[pulumi.Input[_builtins.int]] = None,
                 maxmemory_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 notify_keyspace_events: Optional[pulumi.Input[_builtins.str]] = None,
                 number_of_databases: Optional[pulumi.Input[_builtins.int]] = None,
                 persistence: Optional[pulumi.Input[_builtins.str]] = None,
                 pubsub_client_output_buffer_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 ssl: Optional[pulumi.Input[_builtins.bool]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering DatabaseRedisConfig resources.
        :param pulumi.Input[_builtins.str] acl_channels_default: Determines default pub/sub channels' ACL for new users if an ACL is not supplied. When this option is not defined, `allchannels` is assumed to keep backward compatibility. This option doesn't affect Redis' `acl-pubsub-default` configuration. Supported values are: `allchannels` and `resetchannels`
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the target Redis cluster.
        :param pulumi.Input[_builtins.int] io_threads: The Redis IO thread count.
        :param pulumi.Input[_builtins.int] lfu_decay_time: The LFU maxmemory policy counter decay time in minutes.
        :param pulumi.Input[_builtins.int] lfu_log_factor: The counter logarithm factor for volatile-lfu and allkeys-lfu maxmemory policies.
        :param pulumi.Input[_builtins.str] maxmemory_policy: A string specifying the desired eviction policy for the Redis cluster.Supported values are: `noeviction`, `allkeys-lru`, `allkeys-random`, `volatile-lru`, `volatile-random`, `volatile-ttl`
        :param pulumi.Input[_builtins.str] notify_keyspace_events: The `notify-keyspace-events` option. Requires at least `K` or `E`.
        :param pulumi.Input[_builtins.int] number_of_databases: The number of Redis databases. Changing this will cause a restart of Redis service.
        :param pulumi.Input[_builtins.str] persistence: When persistence is `rdb`, Redis does RDB dumps each 10 minutes if any key is changed. Also RDB dumps are done according to backup schedule for backup purposes. When persistence is `off`, no RDB dumps and backups are done, so data can be lost at any moment if service is restarted for any reason, or if service is powered off. Also service can't be forked.
        :param pulumi.Input[_builtins.int] pubsub_client_output_buffer_limit: The output buffer limit for pub/sub clients in MB. The value is the hard limit, the soft limit is 1/4 of the hard limit. When setting the limit, be mindful of the available memory in the selected service plan.
        :param pulumi.Input[_builtins.bool] ssl: A boolean indicating whether to require SSL to access Redis.
               - When enabled, Redis accepts only SSL connections on port `25061`.
               - When disabled, port `25060` is opened for non-SSL connections, while port `25061` remains available for SSL connections.
        :param pulumi.Input[_builtins.int] timeout: The Redis idle connection timeout in seconds.
        """
        if acl_channels_default is not None:
            pulumi.set(__self__, "acl_channels_default", acl_channels_default)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if io_threads is not None:
            pulumi.set(__self__, "io_threads", io_threads)
        if lfu_decay_time is not None:
            pulumi.set(__self__, "lfu_decay_time", lfu_decay_time)
        if lfu_log_factor is not None:
            pulumi.set(__self__, "lfu_log_factor", lfu_log_factor)
        if maxmemory_policy is not None:
            pulumi.set(__self__, "maxmemory_policy", maxmemory_policy)
        if notify_keyspace_events is not None:
            pulumi.set(__self__, "notify_keyspace_events", notify_keyspace_events)
        if number_of_databases is not None:
            pulumi.set(__self__, "number_of_databases", number_of_databases)
        if persistence is not None:
            pulumi.set(__self__, "persistence", persistence)
        if pubsub_client_output_buffer_limit is not None:
            pulumi.set(__self__, "pubsub_client_output_buffer_limit", pubsub_client_output_buffer_limit)
        if ssl is not None:
            pulumi.set(__self__, "ssl", ssl)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @_builtins.property
    @pulumi.getter(name="aclChannelsDefault")
    def acl_channels_default(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determines default pub/sub channels' ACL for new users if an ACL is not supplied. When this option is not defined, `allchannels` is assumed to keep backward compatibility. This option doesn't affect Redis' `acl-pubsub-default` configuration. Supported values are: `allchannels` and `resetchannels`
        """
        return pulumi.get(self, "acl_channels_default")

    @acl_channels_default.setter
    def acl_channels_default(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "acl_channels_default", value)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the target Redis cluster.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter(name="ioThreads")
    def io_threads(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The Redis IO thread count.
        """
        return pulumi.get(self, "io_threads")

    @io_threads.setter
    def io_threads(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "io_threads", value)

    @_builtins.property
    @pulumi.getter(name="lfuDecayTime")
    def lfu_decay_time(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The LFU maxmemory policy counter decay time in minutes.
        """
        return pulumi.get(self, "lfu_decay_time")

    @lfu_decay_time.setter
    def lfu_decay_time(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "lfu_decay_time", value)

    @_builtins.property
    @pulumi.getter(name="lfuLogFactor")
    def lfu_log_factor(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The counter logarithm factor for volatile-lfu and allkeys-lfu maxmemory policies.
        """
        return pulumi.get(self, "lfu_log_factor")

    @lfu_log_factor.setter
    def lfu_log_factor(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "lfu_log_factor", value)

    @_builtins.property
    @pulumi.getter(name="maxmemoryPolicy")
    def maxmemory_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A string specifying the desired eviction policy for the Redis cluster.Supported values are: `noeviction`, `allkeys-lru`, `allkeys-random`, `volatile-lru`, `volatile-random`, `volatile-ttl`
        """
        return pulumi.get(self, "maxmemory_policy")

    @maxmemory_policy.setter
    def maxmemory_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "maxmemory_policy", value)

    @_builtins.property
    @pulumi.getter(name="notifyKeyspaceEvents")
    def notify_keyspace_events(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The `notify-keyspace-events` option. Requires at least `K` or `E`.
        """
        return pulumi.get(self, "notify_keyspace_events")

    @notify_keyspace_events.setter
    def notify_keyspace_events(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "notify_keyspace_events", value)

    @_builtins.property
    @pulumi.getter(name="numberOfDatabases")
    def number_of_databases(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of Redis databases. Changing this will cause a restart of Redis service.
        """
        return pulumi.get(self, "number_of_databases")

    @number_of_databases.setter
    def number_of_databases(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "number_of_databases", value)

    @_builtins.property
    @pulumi.getter
    def persistence(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        When persistence is `rdb`, Redis does RDB dumps each 10 minutes if any key is changed. Also RDB dumps are done according to backup schedule for backup purposes. When persistence is `off`, no RDB dumps and backups are done, so data can be lost at any moment if service is restarted for any reason, or if service is powered off. Also service can't be forked.
        """
        return pulumi.get(self, "persistence")

    @persistence.setter
    def persistence(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "persistence", value)

    @_builtins.property
    @pulumi.getter(name="pubsubClientOutputBufferLimit")
    def pubsub_client_output_buffer_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The output buffer limit for pub/sub clients in MB. The value is the hard limit, the soft limit is 1/4 of the hard limit. When setting the limit, be mindful of the available memory in the selected service plan.
        """
        return pulumi.get(self, "pubsub_client_output_buffer_limit")

    @pubsub_client_output_buffer_limit.setter
    def pubsub_client_output_buffer_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "pubsub_client_output_buffer_limit", value)

    @_builtins.property
    @pulumi.getter
    def ssl(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        A boolean indicating whether to require SSL to access Redis.
        - When enabled, Redis accepts only SSL connections on port `25061`.
        - When disabled, port `25060` is opened for non-SSL connections, while port `25061` remains available for SSL connections.
        """
        return pulumi.get(self, "ssl")

    @ssl.setter
    def ssl(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "ssl", value)

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The Redis idle connection timeout in seconds.
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "timeout", value)


@pulumi.type_token("digitalocean:index/databaseRedisConfig:DatabaseRedisConfig")
class DatabaseRedisConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acl_channels_default: Optional[pulumi.Input[_builtins.str]] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 io_threads: Optional[pulumi.Input[_builtins.int]] = None,
                 lfu_decay_time: Optional[pulumi.Input[_builtins.int]] = None,
                 lfu_log_factor: Optional[pulumi.Input[_builtins.int]] = None,
                 maxmemory_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 notify_keyspace_events: Optional[pulumi.Input[_builtins.str]] = None,
                 number_of_databases: Optional[pulumi.Input[_builtins.int]] = None,
                 persistence: Optional[pulumi.Input[_builtins.str]] = None,
                 pubsub_client_output_buffer_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 ssl: Optional[pulumi.Input[_builtins.bool]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        Provides a virtual resource that can be used to change advanced configuration
        options for a DigitalOcean managed Redis database cluster.

        > **Note** DigitalOcean managed Redis cluster product is discontinued as of 30 June 2025 and is replaced by the Managed Valkey product. Use the `DatabaseValkeyConfig` resource instead of `DatabaseRedisConfig`

        > **Note** Redis configurations are only removed from state when destroyed. The remote configuration is not unset.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        example_database_cluster = digitalocean.DatabaseCluster("example",
            name="example-redis-cluster",
            engine="redis",
            version="7",
            size=digitalocean.DatabaseSlug.D_B_1_VPCU1_GB,
            region=digitalocean.Region.NYC1,
            node_count=1)
        example = digitalocean.DatabaseRedisConfig("example",
            cluster_id=example_database_cluster.id,
            maxmemory_policy="allkeys-lru",
            notify_keyspace_events="KEA",
            timeout=90)
        ```

        ## Import

        A Redis database cluster's configuration can be imported using the `id` the parent cluster, e.g.

        ```sh
        $ pulumi import digitalocean:index/databaseRedisConfig:DatabaseRedisConfig example 245bcfd0-7f31-4ce6-a2bc-475a116cca97
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] acl_channels_default: Determines default pub/sub channels' ACL for new users if an ACL is not supplied. When this option is not defined, `allchannels` is assumed to keep backward compatibility. This option doesn't affect Redis' `acl-pubsub-default` configuration. Supported values are: `allchannels` and `resetchannels`
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the target Redis cluster.
        :param pulumi.Input[_builtins.int] io_threads: The Redis IO thread count.
        :param pulumi.Input[_builtins.int] lfu_decay_time: The LFU maxmemory policy counter decay time in minutes.
        :param pulumi.Input[_builtins.int] lfu_log_factor: The counter logarithm factor for volatile-lfu and allkeys-lfu maxmemory policies.
        :param pulumi.Input[_builtins.str] maxmemory_policy: A string specifying the desired eviction policy for the Redis cluster.Supported values are: `noeviction`, `allkeys-lru`, `allkeys-random`, `volatile-lru`, `volatile-random`, `volatile-ttl`
        :param pulumi.Input[_builtins.str] notify_keyspace_events: The `notify-keyspace-events` option. Requires at least `K` or `E`.
        :param pulumi.Input[_builtins.int] number_of_databases: The number of Redis databases. Changing this will cause a restart of Redis service.
        :param pulumi.Input[_builtins.str] persistence: When persistence is `rdb`, Redis does RDB dumps each 10 minutes if any key is changed. Also RDB dumps are done according to backup schedule for backup purposes. When persistence is `off`, no RDB dumps and backups are done, so data can be lost at any moment if service is restarted for any reason, or if service is powered off. Also service can't be forked.
        :param pulumi.Input[_builtins.int] pubsub_client_output_buffer_limit: The output buffer limit for pub/sub clients in MB. The value is the hard limit, the soft limit is 1/4 of the hard limit. When setting the limit, be mindful of the available memory in the selected service plan.
        :param pulumi.Input[_builtins.bool] ssl: A boolean indicating whether to require SSL to access Redis.
               - When enabled, Redis accepts only SSL connections on port `25061`.
               - When disabled, port `25060` is opened for non-SSL connections, while port `25061` remains available for SSL connections.
        :param pulumi.Input[_builtins.int] timeout: The Redis idle connection timeout in seconds.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DatabaseRedisConfigArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a virtual resource that can be used to change advanced configuration
        options for a DigitalOcean managed Redis database cluster.

        > **Note** DigitalOcean managed Redis cluster product is discontinued as of 30 June 2025 and is replaced by the Managed Valkey product. Use the `DatabaseValkeyConfig` resource instead of `DatabaseRedisConfig`

        > **Note** Redis configurations are only removed from state when destroyed. The remote configuration is not unset.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        example_database_cluster = digitalocean.DatabaseCluster("example",
            name="example-redis-cluster",
            engine="redis",
            version="7",
            size=digitalocean.DatabaseSlug.D_B_1_VPCU1_GB,
            region=digitalocean.Region.NYC1,
            node_count=1)
        example = digitalocean.DatabaseRedisConfig("example",
            cluster_id=example_database_cluster.id,
            maxmemory_policy="allkeys-lru",
            notify_keyspace_events="KEA",
            timeout=90)
        ```

        ## Import

        A Redis database cluster's configuration can be imported using the `id` the parent cluster, e.g.

        ```sh
        $ pulumi import digitalocean:index/databaseRedisConfig:DatabaseRedisConfig example 245bcfd0-7f31-4ce6-a2bc-475a116cca97
        ```

        :param str resource_name: The name of the resource.
        :param DatabaseRedisConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DatabaseRedisConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acl_channels_default: Optional[pulumi.Input[_builtins.str]] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 io_threads: Optional[pulumi.Input[_builtins.int]] = None,
                 lfu_decay_time: Optional[pulumi.Input[_builtins.int]] = None,
                 lfu_log_factor: Optional[pulumi.Input[_builtins.int]] = None,
                 maxmemory_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 notify_keyspace_events: Optional[pulumi.Input[_builtins.str]] = None,
                 number_of_databases: Optional[pulumi.Input[_builtins.int]] = None,
                 persistence: Optional[pulumi.Input[_builtins.str]] = None,
                 pubsub_client_output_buffer_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 ssl: Optional[pulumi.Input[_builtins.bool]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DatabaseRedisConfigArgs.__new__(DatabaseRedisConfigArgs)

            __props__.__dict__["acl_channels_default"] = acl_channels_default
            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["io_threads"] = io_threads
            __props__.__dict__["lfu_decay_time"] = lfu_decay_time
            __props__.__dict__["lfu_log_factor"] = lfu_log_factor
            __props__.__dict__["maxmemory_policy"] = maxmemory_policy
            __props__.__dict__["notify_keyspace_events"] = notify_keyspace_events
            __props__.__dict__["number_of_databases"] = number_of_databases
            __props__.__dict__["persistence"] = persistence
            __props__.__dict__["pubsub_client_output_buffer_limit"] = pubsub_client_output_buffer_limit
            __props__.__dict__["ssl"] = ssl
            __props__.__dict__["timeout"] = timeout
        super(DatabaseRedisConfig, __self__).__init__(
            'digitalocean:index/databaseRedisConfig:DatabaseRedisConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            acl_channels_default: Optional[pulumi.Input[_builtins.str]] = None,
            cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
            io_threads: Optional[pulumi.Input[_builtins.int]] = None,
            lfu_decay_time: Optional[pulumi.Input[_builtins.int]] = None,
            lfu_log_factor: Optional[pulumi.Input[_builtins.int]] = None,
            maxmemory_policy: Optional[pulumi.Input[_builtins.str]] = None,
            notify_keyspace_events: Optional[pulumi.Input[_builtins.str]] = None,
            number_of_databases: Optional[pulumi.Input[_builtins.int]] = None,
            persistence: Optional[pulumi.Input[_builtins.str]] = None,
            pubsub_client_output_buffer_limit: Optional[pulumi.Input[_builtins.int]] = None,
            ssl: Optional[pulumi.Input[_builtins.bool]] = None,
            timeout: Optional[pulumi.Input[_builtins.int]] = None) -> 'DatabaseRedisConfig':
        """
        Get an existing DatabaseRedisConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] acl_channels_default: Determines default pub/sub channels' ACL for new users if an ACL is not supplied. When this option is not defined, `allchannels` is assumed to keep backward compatibility. This option doesn't affect Redis' `acl-pubsub-default` configuration. Supported values are: `allchannels` and `resetchannels`
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the target Redis cluster.
        :param pulumi.Input[_builtins.int] io_threads: The Redis IO thread count.
        :param pulumi.Input[_builtins.int] lfu_decay_time: The LFU maxmemory policy counter decay time in minutes.
        :param pulumi.Input[_builtins.int] lfu_log_factor: The counter logarithm factor for volatile-lfu and allkeys-lfu maxmemory policies.
        :param pulumi.Input[_builtins.str] maxmemory_policy: A string specifying the desired eviction policy for the Redis cluster.Supported values are: `noeviction`, `allkeys-lru`, `allkeys-random`, `volatile-lru`, `volatile-random`, `volatile-ttl`
        :param pulumi.Input[_builtins.str] notify_keyspace_events: The `notify-keyspace-events` option. Requires at least `K` or `E`.
        :param pulumi.Input[_builtins.int] number_of_databases: The number of Redis databases. Changing this will cause a restart of Redis service.
        :param pulumi.Input[_builtins.str] persistence: When persistence is `rdb`, Redis does RDB dumps each 10 minutes if any key is changed. Also RDB dumps are done according to backup schedule for backup purposes. When persistence is `off`, no RDB dumps and backups are done, so data can be lost at any moment if service is restarted for any reason, or if service is powered off. Also service can't be forked.
        :param pulumi.Input[_builtins.int] pubsub_client_output_buffer_limit: The output buffer limit for pub/sub clients in MB. The value is the hard limit, the soft limit is 1/4 of the hard limit. When setting the limit, be mindful of the available memory in the selected service plan.
        :param pulumi.Input[_builtins.bool] ssl: A boolean indicating whether to require SSL to access Redis.
               - When enabled, Redis accepts only SSL connections on port `25061`.
               - When disabled, port `25060` is opened for non-SSL connections, while port `25061` remains available for SSL connections.
        :param pulumi.Input[_builtins.int] timeout: The Redis idle connection timeout in seconds.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DatabaseRedisConfigState.__new__(_DatabaseRedisConfigState)

        __props__.__dict__["acl_channels_default"] = acl_channels_default
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["io_threads"] = io_threads
        __props__.__dict__["lfu_decay_time"] = lfu_decay_time
        __props__.__dict__["lfu_log_factor"] = lfu_log_factor
        __props__.__dict__["maxmemory_policy"] = maxmemory_policy
        __props__.__dict__["notify_keyspace_events"] = notify_keyspace_events
        __props__.__dict__["number_of_databases"] = number_of_databases
        __props__.__dict__["persistence"] = persistence
        __props__.__dict__["pubsub_client_output_buffer_limit"] = pubsub_client_output_buffer_limit
        __props__.__dict__["ssl"] = ssl
        __props__.__dict__["timeout"] = timeout
        return DatabaseRedisConfig(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="aclChannelsDefault")
    def acl_channels_default(self) -> pulumi.Output[_builtins.str]:
        """
        Determines default pub/sub channels' ACL for new users if an ACL is not supplied. When this option is not defined, `allchannels` is assumed to keep backward compatibility. This option doesn't affect Redis' `acl-pubsub-default` configuration. Supported values are: `allchannels` and `resetchannels`
        """
        return pulumi.get(self, "acl_channels_default")

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the target Redis cluster.
        """
        return pulumi.get(self, "cluster_id")

    @_builtins.property
    @pulumi.getter(name="ioThreads")
    def io_threads(self) -> pulumi.Output[_builtins.int]:
        """
        The Redis IO thread count.
        """
        return pulumi.get(self, "io_threads")

    @_builtins.property
    @pulumi.getter(name="lfuDecayTime")
    def lfu_decay_time(self) -> pulumi.Output[_builtins.int]:
        """
        The LFU maxmemory policy counter decay time in minutes.
        """
        return pulumi.get(self, "lfu_decay_time")

    @_builtins.property
    @pulumi.getter(name="lfuLogFactor")
    def lfu_log_factor(self) -> pulumi.Output[_builtins.int]:
        """
        The counter logarithm factor for volatile-lfu and allkeys-lfu maxmemory policies.
        """
        return pulumi.get(self, "lfu_log_factor")

    @_builtins.property
    @pulumi.getter(name="maxmemoryPolicy")
    def maxmemory_policy(self) -> pulumi.Output[_builtins.str]:
        """
        A string specifying the desired eviction policy for the Redis cluster.Supported values are: `noeviction`, `allkeys-lru`, `allkeys-random`, `volatile-lru`, `volatile-random`, `volatile-ttl`
        """
        return pulumi.get(self, "maxmemory_policy")

    @_builtins.property
    @pulumi.getter(name="notifyKeyspaceEvents")
    def notify_keyspace_events(self) -> pulumi.Output[_builtins.str]:
        """
        The `notify-keyspace-events` option. Requires at least `K` or `E`.
        """
        return pulumi.get(self, "notify_keyspace_events")

    @_builtins.property
    @pulumi.getter(name="numberOfDatabases")
    def number_of_databases(self) -> pulumi.Output[_builtins.int]:
        """
        The number of Redis databases. Changing this will cause a restart of Redis service.
        """
        return pulumi.get(self, "number_of_databases")

    @_builtins.property
    @pulumi.getter
    def persistence(self) -> pulumi.Output[_builtins.str]:
        """
        When persistence is `rdb`, Redis does RDB dumps each 10 minutes if any key is changed. Also RDB dumps are done according to backup schedule for backup purposes. When persistence is `off`, no RDB dumps and backups are done, so data can be lost at any moment if service is restarted for any reason, or if service is powered off. Also service can't be forked.
        """
        return pulumi.get(self, "persistence")

    @_builtins.property
    @pulumi.getter(name="pubsubClientOutputBufferLimit")
    def pubsub_client_output_buffer_limit(self) -> pulumi.Output[_builtins.int]:
        """
        The output buffer limit for pub/sub clients in MB. The value is the hard limit, the soft limit is 1/4 of the hard limit. When setting the limit, be mindful of the available memory in the selected service plan.
        """
        return pulumi.get(self, "pubsub_client_output_buffer_limit")

    @_builtins.property
    @pulumi.getter
    def ssl(self) -> pulumi.Output[_builtins.bool]:
        """
        A boolean indicating whether to require SSL to access Redis.
        - When enabled, Redis accepts only SSL connections on port `25061`.
        - When disabled, port `25060` is opened for non-SSL connections, while port `25061` remains available for SSL connections.
        """
        return pulumi.get(self, "ssl")

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> pulumi.Output[_builtins.int]:
        """
        The Redis idle connection timeout in seconds.
        """
        return pulumi.get(self, "timeout")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetDatabaseClusterResult',
    'AwaitableGetDatabaseClusterResult',
    'get_database_cluster',
    'get_database_cluster_output',
]

@pulumi.output_type
class GetDatabaseClusterResult:
    """
    A collection of values returned by getDatabaseCluster.
    """
    def __init__(__self__, database=None, engine=None, host=None, id=None, maintenance_windows=None, metrics_endpoints=None, name=None, node_count=None, password=None, port=None, private_host=None, private_network_uuid=None, private_uri=None, project_id=None, region=None, size=None, storage_size_mib=None, tags=None, ui_database=None, ui_host=None, ui_password=None, ui_port=None, ui_uri=None, ui_user=None, uri=None, urn=None, user=None, version=None):
        if database and not isinstance(database, str):
            raise TypeError("Expected argument 'database' to be a str")
        pulumi.set(__self__, "database", database)
        if engine and not isinstance(engine, str):
            raise TypeError("Expected argument 'engine' to be a str")
        pulumi.set(__self__, "engine", engine)
        if host and not isinstance(host, str):
            raise TypeError("Expected argument 'host' to be a str")
        pulumi.set(__self__, "host", host)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if maintenance_windows and not isinstance(maintenance_windows, list):
            raise TypeError("Expected argument 'maintenance_windows' to be a list")
        pulumi.set(__self__, "maintenance_windows", maintenance_windows)
        if metrics_endpoints and not isinstance(metrics_endpoints, list):
            raise TypeError("Expected argument 'metrics_endpoints' to be a list")
        pulumi.set(__self__, "metrics_endpoints", metrics_endpoints)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if node_count and not isinstance(node_count, int):
            raise TypeError("Expected argument 'node_count' to be a int")
        pulumi.set(__self__, "node_count", node_count)
        if password and not isinstance(password, str):
            raise TypeError("Expected argument 'password' to be a str")
        pulumi.set(__self__, "password", password)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if private_host and not isinstance(private_host, str):
            raise TypeError("Expected argument 'private_host' to be a str")
        pulumi.set(__self__, "private_host", private_host)
        if private_network_uuid and not isinstance(private_network_uuid, str):
            raise TypeError("Expected argument 'private_network_uuid' to be a str")
        pulumi.set(__self__, "private_network_uuid", private_network_uuid)
        if private_uri and not isinstance(private_uri, str):
            raise TypeError("Expected argument 'private_uri' to be a str")
        pulumi.set(__self__, "private_uri", private_uri)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if size and not isinstance(size, str):
            raise TypeError("Expected argument 'size' to be a str")
        pulumi.set(__self__, "size", size)
        if storage_size_mib and not isinstance(storage_size_mib, str):
            raise TypeError("Expected argument 'storage_size_mib' to be a str")
        pulumi.set(__self__, "storage_size_mib", storage_size_mib)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if ui_database and not isinstance(ui_database, str):
            raise TypeError("Expected argument 'ui_database' to be a str")
        pulumi.set(__self__, "ui_database", ui_database)
        if ui_host and not isinstance(ui_host, str):
            raise TypeError("Expected argument 'ui_host' to be a str")
        pulumi.set(__self__, "ui_host", ui_host)
        if ui_password and not isinstance(ui_password, str):
            raise TypeError("Expected argument 'ui_password' to be a str")
        pulumi.set(__self__, "ui_password", ui_password)
        if ui_port and not isinstance(ui_port, int):
            raise TypeError("Expected argument 'ui_port' to be a int")
        pulumi.set(__self__, "ui_port", ui_port)
        if ui_uri and not isinstance(ui_uri, str):
            raise TypeError("Expected argument 'ui_uri' to be a str")
        pulumi.set(__self__, "ui_uri", ui_uri)
        if ui_user and not isinstance(ui_user, str):
            raise TypeError("Expected argument 'ui_user' to be a str")
        pulumi.set(__self__, "ui_user", ui_user)
        if uri and not isinstance(uri, str):
            raise TypeError("Expected argument 'uri' to be a str")
        pulumi.set(__self__, "uri", uri)
        if urn and not isinstance(urn, str):
            raise TypeError("Expected argument 'urn' to be a str")
        pulumi.set(__self__, "urn", urn)
        if user and not isinstance(user, str):
            raise TypeError("Expected argument 'user' to be a str")
        pulumi.set(__self__, "user", user)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)

    @_builtins.property
    @pulumi.getter
    def database(self) -> _builtins.str:
        """
        Name of the cluster's default database.
        """
        return pulumi.get(self, "database")

    @_builtins.property
    @pulumi.getter
    def engine(self) -> _builtins.str:
        """
        Database engine used by the cluster (ex. `pg` for PostgreSQL).
        """
        return pulumi.get(self, "engine")

    @_builtins.property
    @pulumi.getter
    def host(self) -> _builtins.str:
        """
        Database cluster's hostname.
        """
        return pulumi.get(self, "host")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="maintenanceWindows")
    def maintenance_windows(self) -> Sequence['outputs.GetDatabaseClusterMaintenanceWindowResult']:
        """
        Defines when the automatic maintenance should be performed for the database cluster.
        """
        return pulumi.get(self, "maintenance_windows")

    @_builtins.property
    @pulumi.getter(name="metricsEndpoints")
    def metrics_endpoints(self) -> Sequence[_builtins.str]:
        """
        A list of metrics endpoints for the database cluster, providing URLs to access Prometheus-compatible metrics.
        """
        return pulumi.get(self, "metrics_endpoints")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="nodeCount")
    def node_count(self) -> _builtins.int:
        """
        Number of nodes that will be included in the cluster.
        """
        return pulumi.get(self, "node_count")

    @_builtins.property
    @pulumi.getter
    def password(self) -> _builtins.str:
        """
        Password for the cluster's default user.
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        Network port that the database cluster is listening on.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter(name="privateHost")
    def private_host(self) -> _builtins.str:
        """
        Same as `host`, but only accessible from resources within the account and in the same region.
        """
        return pulumi.get(self, "private_host")

    @_builtins.property
    @pulumi.getter(name="privateNetworkUuid")
    def private_network_uuid(self) -> _builtins.str:
        """
        The ID of the VPC where the database cluster is located.
        """
        return pulumi.get(self, "private_network_uuid")

    @_builtins.property
    @pulumi.getter(name="privateUri")
    def private_uri(self) -> _builtins.str:
        """
        Same as `uri`, but only accessible from resources within the account and in the same region.
        """
        return pulumi.get(self, "private_uri")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        The ID of the project that the database cluster is assigned to.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        DigitalOcean region where the cluster will reside.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def size(self) -> _builtins.str:
        """
        Database droplet size associated with the cluster (ex. `db-s-1vcpu-1gb`).
        """
        return pulumi.get(self, "size")

    @_builtins.property
    @pulumi.getter(name="storageSizeMib")
    def storage_size_mib(self) -> _builtins.str:
        return pulumi.get(self, "storage_size_mib")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[Sequence[_builtins.str]]:
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="uiDatabase")
    def ui_database(self) -> _builtins.str:
        """
        Name of the OpenSearch dashboard db.
        """
        return pulumi.get(self, "ui_database")

    @_builtins.property
    @pulumi.getter(name="uiHost")
    def ui_host(self) -> _builtins.str:
        """
        Hostname for the OpenSearch dashboard.
        """
        return pulumi.get(self, "ui_host")

    @_builtins.property
    @pulumi.getter(name="uiPassword")
    def ui_password(self) -> _builtins.str:
        """
        Password for the OpenSearch dashboard's default user.
        """
        return pulumi.get(self, "ui_password")

    @_builtins.property
    @pulumi.getter(name="uiPort")
    def ui_port(self) -> _builtins.int:
        """
        Network port that the OpenSearch dashboard is listening on.
        """
        return pulumi.get(self, "ui_port")

    @_builtins.property
    @pulumi.getter(name="uiUri")
    def ui_uri(self) -> _builtins.str:
        """
        The full URI for connecting to the OpenSearch dashboard.
        """
        return pulumi.get(self, "ui_uri")

    @_builtins.property
    @pulumi.getter(name="uiUser")
    def ui_user(self) -> _builtins.str:
        """
        Username for OpenSearch dashboard's default user.
        """
        return pulumi.get(self, "ui_user")

    @_builtins.property
    @pulumi.getter
    def uri(self) -> _builtins.str:
        """
        The full URI for connecting to the database cluster.
        """
        return pulumi.get(self, "uri")

    @_builtins.property
    @pulumi.getter
    def urn(self) -> _builtins.str:
        """
        The uniform resource name of the database cluster.
        """
        return pulumi.get(self, "urn")

    @_builtins.property
    @pulumi.getter
    def user(self) -> _builtins.str:
        """
        Username for the cluster's default user.
        """
        return pulumi.get(self, "user")

    @_builtins.property
    @pulumi.getter
    def version(self) -> _builtins.str:
        """
        Engine version used by the cluster (ex. `11` for PostgreSQL 11).
        """
        return pulumi.get(self, "version")


class AwaitableGetDatabaseClusterResult(GetDatabaseClusterResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabaseClusterResult(
            database=self.database,
            engine=self.engine,
            host=self.host,
            id=self.id,
            maintenance_windows=self.maintenance_windows,
            metrics_endpoints=self.metrics_endpoints,
            name=self.name,
            node_count=self.node_count,
            password=self.password,
            port=self.port,
            private_host=self.private_host,
            private_network_uuid=self.private_network_uuid,
            private_uri=self.private_uri,
            project_id=self.project_id,
            region=self.region,
            size=self.size,
            storage_size_mib=self.storage_size_mib,
            tags=self.tags,
            ui_database=self.ui_database,
            ui_host=self.ui_host,
            ui_password=self.ui_password,
            ui_port=self.ui_port,
            ui_uri=self.ui_uri,
            ui_user=self.ui_user,
            uri=self.uri,
            urn=self.urn,
            user=self.user,
            version=self.version)


def get_database_cluster(name: Optional[_builtins.str] = None,
                         tags: Optional[Sequence[_builtins.str]] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabaseClusterResult:
    """
    Provides information on a DigitalOcean database cluster resource.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_database_cluster(name="example-cluster")
    pulumi.export("databaseOutput", example.uri)
    ```


    :param _builtins.str name: The name of the database cluster.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('digitalocean:index/getDatabaseCluster:getDatabaseCluster', __args__, opts=opts, typ=GetDatabaseClusterResult).value

    return AwaitableGetDatabaseClusterResult(
        database=pulumi.get(__ret__, 'database'),
        engine=pulumi.get(__ret__, 'engine'),
        host=pulumi.get(__ret__, 'host'),
        id=pulumi.get(__ret__, 'id'),
        maintenance_windows=pulumi.get(__ret__, 'maintenance_windows'),
        metrics_endpoints=pulumi.get(__ret__, 'metrics_endpoints'),
        name=pulumi.get(__ret__, 'name'),
        node_count=pulumi.get(__ret__, 'node_count'),
        password=pulumi.get(__ret__, 'password'),
        port=pulumi.get(__ret__, 'port'),
        private_host=pulumi.get(__ret__, 'private_host'),
        private_network_uuid=pulumi.get(__ret__, 'private_network_uuid'),
        private_uri=pulumi.get(__ret__, 'private_uri'),
        project_id=pulumi.get(__ret__, 'project_id'),
        region=pulumi.get(__ret__, 'region'),
        size=pulumi.get(__ret__, 'size'),
        storage_size_mib=pulumi.get(__ret__, 'storage_size_mib'),
        tags=pulumi.get(__ret__, 'tags'),
        ui_database=pulumi.get(__ret__, 'ui_database'),
        ui_host=pulumi.get(__ret__, 'ui_host'),
        ui_password=pulumi.get(__ret__, 'ui_password'),
        ui_port=pulumi.get(__ret__, 'ui_port'),
        ui_uri=pulumi.get(__ret__, 'ui_uri'),
        ui_user=pulumi.get(__ret__, 'ui_user'),
        uri=pulumi.get(__ret__, 'uri'),
        urn=pulumi.get(__ret__, 'urn'),
        user=pulumi.get(__ret__, 'user'),
        version=pulumi.get(__ret__, 'version'))
def get_database_cluster_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                                tags: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDatabaseClusterResult]:
    """
    Provides information on a DigitalOcean database cluster resource.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_database_cluster(name="example-cluster")
    pulumi.export("databaseOutput", example.uri)
    ```


    :param _builtins.str name: The name of the database cluster.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['tags'] = tags
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('digitalocean:index/getDatabaseCluster:getDatabaseCluster', __args__, opts=opts, typ=GetDatabaseClusterResult)
    return __ret__.apply(lambda __response__: GetDatabaseClusterResult(
        database=pulumi.get(__response__, 'database'),
        engine=pulumi.get(__response__, 'engine'),
        host=pulumi.get(__response__, 'host'),
        id=pulumi.get(__response__, 'id'),
        maintenance_windows=pulumi.get(__response__, 'maintenance_windows'),
        metrics_endpoints=pulumi.get(__response__, 'metrics_endpoints'),
        name=pulumi.get(__response__, 'name'),
        node_count=pulumi.get(__response__, 'node_count'),
        password=pulumi.get(__response__, 'password'),
        port=pulumi.get(__response__, 'port'),
        private_host=pulumi.get(__response__, 'private_host'),
        private_network_uuid=pulumi.get(__response__, 'private_network_uuid'),
        private_uri=pulumi.get(__response__, 'private_uri'),
        project_id=pulumi.get(__response__, 'project_id'),
        region=pulumi.get(__response__, 'region'),
        size=pulumi.get(__response__, 'size'),
        storage_size_mib=pulumi.get(__response__, 'storage_size_mib'),
        tags=pulumi.get(__response__, 'tags'),
        ui_database=pulumi.get(__response__, 'ui_database'),
        ui_host=pulumi.get(__response__, 'ui_host'),
        ui_password=pulumi.get(__response__, 'ui_password'),
        ui_port=pulumi.get(__response__, 'ui_port'),
        ui_uri=pulumi.get(__response__, 'ui_uri'),
        ui_user=pulumi.get(__response__, 'ui_user'),
        uri=pulumi.get(__response__, 'uri'),
        urn=pulumi.get(__response__, 'urn'),
        user=pulumi.get(__response__, 'user'),
        version=pulumi.get(__response__, 'version')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

apiEndpoint: str
"""
The URL to use for the DigitalOcean API.
"""

httpRetryMax: Optional[int]
"""
The maximum number of retries on a failed API request.
"""

httpRetryWaitMax: Optional[float]
"""
The maximum wait time (in seconds) between failed API requests.
"""

httpRetryWaitMin: Optional[float]
"""
The minimum wait time (in seconds) between failed API requests.
"""

requestsPerSecond: Optional[float]
"""
The rate of requests per second to limit the HTTP client.
"""

spacesAccessId: Optional[str]
"""
The access key ID for Spaces API operations.
"""

spacesEndpoint: Optional[str]
"""
The URL to use for the DigitalOcean Spaces API.
"""

spacesSecretKey: Optional[str]
"""
The secret access key for Spaces API operations.
"""

token: Optional[str]
"""
The token key for API operations.
"""




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['VpcArgs', 'Vpc']

@pulumi.input_type
class VpcArgs:
    def __init__(__self__, *,
                 region: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 ip_range: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Vpc resource.
        :param pulumi.Input[_builtins.str] region: The DigitalOcean region slug for the VPC's location.
        :param pulumi.Input[_builtins.str] description: A free-form text field up to a limit of 255 characters to describe the VPC.
        :param pulumi.Input[_builtins.str] ip_range: The range of IP addresses for the VPC in CIDR notation. Network ranges cannot overlap with other networks in the same account and must be in range of private addresses as defined in RFC1918. It may not be larger than `/16` or smaller than `/24`.
        :param pulumi.Input[_builtins.str] name: A name for the VPC. Must be unique and contain alphanumeric characters, dashes, and periods only.
        """
        pulumi.set(__self__, "region", region)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ip_range is not None:
            pulumi.set(__self__, "ip_range", ip_range)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Input[_builtins.str]:
        """
        The DigitalOcean region slug for the VPC's location.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A free-form text field up to a limit of 255 characters to describe the VPC.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="ipRange")
    def ip_range(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The range of IP addresses for the VPC in CIDR notation. Network ranges cannot overlap with other networks in the same account and must be in range of private addresses as defined in RFC1918. It may not be larger than `/16` or smaller than `/24`.
        """
        return pulumi.get(self, "ip_range")

    @ip_range.setter
    def ip_range(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ip_range", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A name for the VPC. Must be unique and contain alphanumeric characters, dashes, and periods only.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _VpcState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 default: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 ip_range: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 vpc_urn: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Vpc resources.
        :param pulumi.Input[_builtins.str] created_at: The date and time of when the VPC was created.
        :param pulumi.Input[_builtins.bool] default: A boolean indicating whether or not the VPC is the default one for the region.
        :param pulumi.Input[_builtins.str] description: A free-form text field up to a limit of 255 characters to describe the VPC.
        :param pulumi.Input[_builtins.str] ip_range: The range of IP addresses for the VPC in CIDR notation. Network ranges cannot overlap with other networks in the same account and must be in range of private addresses as defined in RFC1918. It may not be larger than `/16` or smaller than `/24`.
        :param pulumi.Input[_builtins.str] name: A name for the VPC. Must be unique and contain alphanumeric characters, dashes, and periods only.
        :param pulumi.Input[_builtins.str] region: The DigitalOcean region slug for the VPC's location.
        :param pulumi.Input[_builtins.str] vpc_urn: The uniform resource name (URN) for the VPC.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if default is not None:
            pulumi.set(__self__, "default", default)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ip_range is not None:
            pulumi.set(__self__, "ip_range", ip_range)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if vpc_urn is not None:
            pulumi.set(__self__, "vpc_urn", vpc_urn)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of when the VPC was created.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter
    def default(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        A boolean indicating whether or not the VPC is the default one for the region.
        """
        return pulumi.get(self, "default")

    @default.setter
    def default(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "default", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A free-form text field up to a limit of 255 characters to describe the VPC.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="ipRange")
    def ip_range(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The range of IP addresses for the VPC in CIDR notation. Network ranges cannot overlap with other networks in the same account and must be in range of private addresses as defined in RFC1918. It may not be larger than `/16` or smaller than `/24`.
        """
        return pulumi.get(self, "ip_range")

    @ip_range.setter
    def ip_range(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ip_range", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A name for the VPC. Must be unique and contain alphanumeric characters, dashes, and periods only.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The DigitalOcean region slug for the VPC's location.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="vpcUrn")
    def vpc_urn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The uniform resource name (URN) for the VPC.
        """
        return pulumi.get(self, "vpc_urn")

    @vpc_urn.setter
    def vpc_urn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "vpc_urn", value)


@pulumi.type_token("digitalocean:index/vpc:Vpc")
class Vpc(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 ip_range: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Provides a [DigitalOcean VPC](https://docs.digitalocean.com/reference/api/digitalocean/#tag/VPCs) resource.

        VPCs are virtual networks containing resources that can communicate with each
        other in full isolation, using private IP addresses.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        example = digitalocean.Vpc("example",
            name="example-project-network",
            region="nyc3",
            ip_range="10.10.10.0/24")
        ```

        ### Resource Assignment

        `Droplet`, `KubernetesCluster`,
        `digitalocean_load_balancer`, and `DatabaseCluster` resources
        may be assigned to a VPC by referencing its `id`. For example:

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        example = digitalocean.Vpc("example",
            name="example-project-network",
            region="nyc3")
        example_droplet = digitalocean.Droplet("example",
            name="example-01",
            size=digitalocean.DropletSlug.DROPLET_S1_VCPU1_GB,
            image="ubuntu-18-04-x64",
            region=digitalocean.Region.NYC3,
            vpc_uuid=example.id)
        ```

        ## Import

        A VPC can be imported using its `id`, e.g.

        ```sh
        $ pulumi import digitalocean:index/vpc:Vpc example 506f78a4-e098-11e5-ad9f-000f53306ae1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: A free-form text field up to a limit of 255 characters to describe the VPC.
        :param pulumi.Input[_builtins.str] ip_range: The range of IP addresses for the VPC in CIDR notation. Network ranges cannot overlap with other networks in the same account and must be in range of private addresses as defined in RFC1918. It may not be larger than `/16` or smaller than `/24`.
        :param pulumi.Input[_builtins.str] name: A name for the VPC. Must be unique and contain alphanumeric characters, dashes, and periods only.
        :param pulumi.Input[_builtins.str] region: The DigitalOcean region slug for the VPC's location.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VpcArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a [DigitalOcean VPC](https://docs.digitalocean.com/reference/api/digitalocean/#tag/VPCs) resource.

        VPCs are virtual networks containing resources that can communicate with each
        other in full isolation, using private IP addresses.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        example = digitalocean.Vpc("example",
            name="example-project-network",
            region="nyc3",
            ip_range="10.10.10.0/24")
        ```

        ### Resource Assignment

        `Droplet`, `KubernetesCluster`,
        `digitalocean_load_balancer`, and `DatabaseCluster` resources
        may be assigned to a VPC by referencing its `id`. For example:

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        example = digitalocean.Vpc("example",
            name="example-project-network",
            region="nyc3")
        example_droplet = digitalocean.Droplet("example",
            name="example-01",
            size=digitalocean.DropletSlug.DROPLET_S1_VCPU1_GB,
            image="ubuntu-18-04-x64",
            region=digitalocean.Region.NYC3,
            vpc_uuid=example.id)
        ```

        ## Import

        A VPC can be imported using its `id`, e.g.

        ```sh
        $ pulumi import digitalocean:index/vpc:Vpc example 506f78a4-e098-11e5-ad9f-000f53306ae1
        ```

        :param str resource_name: The name of the resource.
        :param VpcArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VpcArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 ip_range: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VpcArgs.__new__(VpcArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["ip_range"] = ip_range
            __props__.__dict__["name"] = name
            if region is None and not opts.urn:
                raise TypeError("Missing required property 'region'")
            __props__.__dict__["region"] = region
            __props__.__dict__["created_at"] = None
            __props__.__dict__["default"] = None
            __props__.__dict__["vpc_urn"] = None
        super(Vpc, __self__).__init__(
            'digitalocean:index/vpc:Vpc',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            default: Optional[pulumi.Input[_builtins.bool]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            ip_range: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            vpc_urn: Optional[pulumi.Input[_builtins.str]] = None) -> 'Vpc':
        """
        Get an existing Vpc resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_at: The date and time of when the VPC was created.
        :param pulumi.Input[_builtins.bool] default: A boolean indicating whether or not the VPC is the default one for the region.
        :param pulumi.Input[_builtins.str] description: A free-form text field up to a limit of 255 characters to describe the VPC.
        :param pulumi.Input[_builtins.str] ip_range: The range of IP addresses for the VPC in CIDR notation. Network ranges cannot overlap with other networks in the same account and must be in range of private addresses as defined in RFC1918. It may not be larger than `/16` or smaller than `/24`.
        :param pulumi.Input[_builtins.str] name: A name for the VPC. Must be unique and contain alphanumeric characters, dashes, and periods only.
        :param pulumi.Input[_builtins.str] region: The DigitalOcean region slug for the VPC's location.
        :param pulumi.Input[_builtins.str] vpc_urn: The uniform resource name (URN) for the VPC.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VpcState.__new__(_VpcState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["default"] = default
        __props__.__dict__["description"] = description
        __props__.__dict__["ip_range"] = ip_range
        __props__.__dict__["name"] = name
        __props__.__dict__["region"] = region
        __props__.__dict__["vpc_urn"] = vpc_urn
        return Vpc(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of when the VPC was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def default(self) -> pulumi.Output[_builtins.bool]:
        """
        A boolean indicating whether or not the VPC is the default one for the region.
        """
        return pulumi.get(self, "default")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        A free-form text field up to a limit of 255 characters to describe the VPC.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="ipRange")
    def ip_range(self) -> pulumi.Output[_builtins.str]:
        """
        The range of IP addresses for the VPC in CIDR notation. Network ranges cannot overlap with other networks in the same account and must be in range of private addresses as defined in RFC1918. It may not be larger than `/16` or smaller than `/24`.
        """
        return pulumi.get(self, "ip_range")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        A name for the VPC. Must be unique and contain alphanumeric characters, dashes, and periods only.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The DigitalOcean region slug for the VPC's location.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="vpcUrn")
    def vpc_urn(self) -> pulumi.Output[_builtins.str]:
        """
        The uniform resource name (URN) for the VPC.
        """
        return pulumi.get(self, "vpc_urn")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetVolumeResult',
    'AwaitableGetVolumeResult',
    'get_volume',
    'get_volume_output',
]

@pulumi.output_type
class GetVolumeResult:
    """
    A collection of values returned by getVolume.
    """
    def __init__(__self__, description=None, droplet_ids=None, filesystem_label=None, filesystem_type=None, id=None, name=None, region=None, size=None, tags=None, urn=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if droplet_ids and not isinstance(droplet_ids, list):
            raise TypeError("Expected argument 'droplet_ids' to be a list")
        pulumi.set(__self__, "droplet_ids", droplet_ids)
        if filesystem_label and not isinstance(filesystem_label, str):
            raise TypeError("Expected argument 'filesystem_label' to be a str")
        pulumi.set(__self__, "filesystem_label", filesystem_label)
        if filesystem_type and not isinstance(filesystem_type, str):
            raise TypeError("Expected argument 'filesystem_type' to be a str")
        pulumi.set(__self__, "filesystem_type", filesystem_type)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if size and not isinstance(size, int):
            raise TypeError("Expected argument 'size' to be a int")
        pulumi.set(__self__, "size", size)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if urn and not isinstance(urn, str):
            raise TypeError("Expected argument 'urn' to be a str")
        pulumi.set(__self__, "urn", urn)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        """
        Text describing a block storage volume.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="dropletIds")
    def droplet_ids(self) -> Sequence[_builtins.int]:
        """
        A list of associated Droplet ids.
        """
        return pulumi.get(self, "droplet_ids")

    @_builtins.property
    @pulumi.getter(name="filesystemLabel")
    def filesystem_label(self) -> _builtins.str:
        """
        Filesystem label currently in-use on the block storage volume.
        """
        return pulumi.get(self, "filesystem_label")

    @_builtins.property
    @pulumi.getter(name="filesystemType")
    def filesystem_type(self) -> _builtins.str:
        """
        Filesystem type currently in-use on the block storage volume.
        """
        return pulumi.get(self, "filesystem_type")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def size(self) -> _builtins.int:
        """
        The size of the block storage volume in GiB.
        """
        return pulumi.get(self, "size")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        A list of the tags associated to the Volume.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def urn(self) -> _builtins.str:
        """
        The uniform resource name for the storage volume.
        """
        return pulumi.get(self, "urn")


class AwaitableGetVolumeResult(GetVolumeResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVolumeResult(
            description=self.description,
            droplet_ids=self.droplet_ids,
            filesystem_label=self.filesystem_label,
            filesystem_type=self.filesystem_type,
            id=self.id,
            name=self.name,
            region=self.region,
            size=self.size,
            tags=self.tags,
            urn=self.urn)


def get_volume(description: Optional[_builtins.str] = None,
               name: Optional[_builtins.str] = None,
               region: Optional[_builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVolumeResult:
    """
    Get information on a volume for use in other resources. This data source provides
    all of the volumes properties as configured on your DigitalOcean account. This is
    useful if the volume in question is not managed by the provider or you need to utilize
    any of the volumes data.

    An error is triggered if the provided volume name does not exist.

    ## Example Usage

    Get the volume:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_volume(name="app-data",
        region="nyc3")
    ```

    Reuse the data about a volume to attach it to a Droplet:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_volume(name="app-data",
        region="nyc3")
    example_droplet = digitalocean.Droplet("example",
        name="foo",
        size=digitalocean.DropletSlug.DROPLET_S1_VCPU1_GB,
        image="ubuntu-18-04-x64",
        region=digitalocean.Region.NYC3)
    foobar = digitalocean.VolumeAttachment("foobar",
        droplet_id=example_droplet.id,
        volume_id=example.id)
    ```


    :param _builtins.str description: Text describing a block storage volume.
    :param _builtins.str name: The name of block storage volume.
    :param _builtins.str region: The region the block storage volume is provisioned in.
    """
    __args__ = dict()
    __args__['description'] = description
    __args__['name'] = name
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('digitalocean:index/getVolume:getVolume', __args__, opts=opts, typ=GetVolumeResult).value

    return AwaitableGetVolumeResult(
        description=pulumi.get(__ret__, 'description'),
        droplet_ids=pulumi.get(__ret__, 'droplet_ids'),
        filesystem_label=pulumi.get(__ret__, 'filesystem_label'),
        filesystem_type=pulumi.get(__ret__, 'filesystem_type'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        region=pulumi.get(__ret__, 'region'),
        size=pulumi.get(__ret__, 'size'),
        tags=pulumi.get(__ret__, 'tags'),
        urn=pulumi.get(__ret__, 'urn'))
def get_volume_output(description: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      name: Optional[pulumi.Input[_builtins.str]] = None,
                      region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetVolumeResult]:
    """
    Get information on a volume for use in other resources. This data source provides
    all of the volumes properties as configured on your DigitalOcean account. This is
    useful if the volume in question is not managed by the provider or you need to utilize
    any of the volumes data.

    An error is triggered if the provided volume name does not exist.

    ## Example Usage

    Get the volume:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_volume(name="app-data",
        region="nyc3")
    ```

    Reuse the data about a volume to attach it to a Droplet:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_volume(name="app-data",
        region="nyc3")
    example_droplet = digitalocean.Droplet("example",
        name="foo",
        size=digitalocean.DropletSlug.DROPLET_S1_VCPU1_GB,
        image="ubuntu-18-04-x64",
        region=digitalocean.Region.NYC3)
    foobar = digitalocean.VolumeAttachment("foobar",
        droplet_id=example_droplet.id,
        volume_id=example.id)
    ```


    :param _builtins.str description: Text describing a block storage volume.
    :param _builtins.str name: The name of block storage volume.
    :param _builtins.str region: The region the block storage volume is provisioned in.
    """
    __args__ = dict()
    __args__['description'] = description
    __args__['name'] = name
    __args__['region'] = region
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('digitalocean:index/getVolume:getVolume', __args__, opts=opts, typ=GetVolumeResult)
    return __ret__.apply(lambda __response__: GetVolumeResult(
        description=pulumi.get(__response__, 'description'),
        droplet_ids=pulumi.get(__response__, 'droplet_ids'),
        filesystem_label=pulumi.get(__response__, 'filesystem_label'),
        filesystem_type=pulumi.get(__response__, 'filesystem_type'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        region=pulumi.get(__response__, 'region'),
        size=pulumi.get(__response__, 'size'),
        tags=pulumi.get(__response__, 'tags'),
        urn=pulumi.get(__response__, 'urn')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['DatabaseMongodbConfigArgs', 'DatabaseMongodbConfig']

@pulumi.input_type
class DatabaseMongodbConfigArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[_builtins.str],
                 default_read_concern: Optional[pulumi.Input[_builtins.str]] = None,
                 default_write_concern: Optional[pulumi.Input[_builtins.str]] = None,
                 slow_op_threshold_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 transaction_lifetime_limit_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 verbosity: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a DatabaseMongodbConfig resource.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the target MongoDB cluster.
        :param pulumi.Input[_builtins.str] default_read_concern: Specifies the default consistency behavior of reads from the database. Data that is returned from the query with may or may not have been acknowledged by all nodes in the replicaset depending on this value. Learn more [here](https://www.mongodb.com/docs/manual/reference/read-concern/).
        :param pulumi.Input[_builtins.str] default_write_concern: Describes the level of acknowledgment requested from MongoDB for write operations clusters. This field can set to either `majority` or a number`0...n` which will describe the number of nodes that must acknowledge the write operation before it is fully accepted. Setting to `0` will request no acknowledgement of the write operation. Learn more [here](https://www.mongodb.com/docs/manual/reference/write-concern/).
        :param pulumi.Input[_builtins.int] slow_op_threshold_ms: Operations that run for longer than this threshold are considered slow which are then recorded to the diagnostic logs. Higher log levels (verbosity) will record all operations regardless of this threshold on the primary node. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/configuration-options/#mongodb-setting-operationProfiling.slowOpThresholdMs).
        :param pulumi.Input[_builtins.int] transaction_lifetime_limit_seconds: Specifies the lifetime of multi-document transactions. Transactions that exceed this limit are considered expired and will be aborted by a periodic cleanup process. The cleanup process runs every `transactionLifetimeLimitSeconds/2 seconds` or at least once every 60 seconds. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/parameters/#mongodb-parameter-param.transactionLifetimeLimitSeconds).
        :param pulumi.Input[_builtins.int] verbosity: The log message verbosity level. The verbosity level determines the amount of Informational and Debug messages MongoDB outputs. 0 includes informational messages while 1...5 increases the level to include debug messages. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/configuration-options/#mongodb-setting-systemLog.verbosity).
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        if default_read_concern is not None:
            pulumi.set(__self__, "default_read_concern", default_read_concern)
        if default_write_concern is not None:
            pulumi.set(__self__, "default_write_concern", default_write_concern)
        if slow_op_threshold_ms is not None:
            pulumi.set(__self__, "slow_op_threshold_ms", slow_op_threshold_ms)
        if transaction_lifetime_limit_seconds is not None:
            pulumi.set(__self__, "transaction_lifetime_limit_seconds", transaction_lifetime_limit_seconds)
        if verbosity is not None:
            pulumi.set(__self__, "verbosity", verbosity)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the target MongoDB cluster.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter(name="defaultReadConcern")
    def default_read_concern(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the default consistency behavior of reads from the database. Data that is returned from the query with may or may not have been acknowledged by all nodes in the replicaset depending on this value. Learn more [here](https://www.mongodb.com/docs/manual/reference/read-concern/).
        """
        return pulumi.get(self, "default_read_concern")

    @default_read_concern.setter
    def default_read_concern(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_read_concern", value)

    @_builtins.property
    @pulumi.getter(name="defaultWriteConcern")
    def default_write_concern(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Describes the level of acknowledgment requested from MongoDB for write operations clusters. This field can set to either `majority` or a number`0...n` which will describe the number of nodes that must acknowledge the write operation before it is fully accepted. Setting to `0` will request no acknowledgement of the write operation. Learn more [here](https://www.mongodb.com/docs/manual/reference/write-concern/).
        """
        return pulumi.get(self, "default_write_concern")

    @default_write_concern.setter
    def default_write_concern(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_write_concern", value)

    @_builtins.property
    @pulumi.getter(name="slowOpThresholdMs")
    def slow_op_threshold_ms(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Operations that run for longer than this threshold are considered slow which are then recorded to the diagnostic logs. Higher log levels (verbosity) will record all operations regardless of this threshold on the primary node. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/configuration-options/#mongodb-setting-operationProfiling.slowOpThresholdMs).
        """
        return pulumi.get(self, "slow_op_threshold_ms")

    @slow_op_threshold_ms.setter
    def slow_op_threshold_ms(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "slow_op_threshold_ms", value)

    @_builtins.property
    @pulumi.getter(name="transactionLifetimeLimitSeconds")
    def transaction_lifetime_limit_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the lifetime of multi-document transactions. Transactions that exceed this limit are considered expired and will be aborted by a periodic cleanup process. The cleanup process runs every `transactionLifetimeLimitSeconds/2 seconds` or at least once every 60 seconds. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/parameters/#mongodb-parameter-param.transactionLifetimeLimitSeconds).
        """
        return pulumi.get(self, "transaction_lifetime_limit_seconds")

    @transaction_lifetime_limit_seconds.setter
    def transaction_lifetime_limit_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "transaction_lifetime_limit_seconds", value)

    @_builtins.property
    @pulumi.getter
    def verbosity(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The log message verbosity level. The verbosity level determines the amount of Informational and Debug messages MongoDB outputs. 0 includes informational messages while 1...5 increases the level to include debug messages. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/configuration-options/#mongodb-setting-systemLog.verbosity).
        """
        return pulumi.get(self, "verbosity")

    @verbosity.setter
    def verbosity(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "verbosity", value)


@pulumi.input_type
class _DatabaseMongodbConfigState:
    def __init__(__self__, *,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 default_read_concern: Optional[pulumi.Input[_builtins.str]] = None,
                 default_write_concern: Optional[pulumi.Input[_builtins.str]] = None,
                 slow_op_threshold_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 transaction_lifetime_limit_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 verbosity: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering DatabaseMongodbConfig resources.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the target MongoDB cluster.
        :param pulumi.Input[_builtins.str] default_read_concern: Specifies the default consistency behavior of reads from the database. Data that is returned from the query with may or may not have been acknowledged by all nodes in the replicaset depending on this value. Learn more [here](https://www.mongodb.com/docs/manual/reference/read-concern/).
        :param pulumi.Input[_builtins.str] default_write_concern: Describes the level of acknowledgment requested from MongoDB for write operations clusters. This field can set to either `majority` or a number`0...n` which will describe the number of nodes that must acknowledge the write operation before it is fully accepted. Setting to `0` will request no acknowledgement of the write operation. Learn more [here](https://www.mongodb.com/docs/manual/reference/write-concern/).
        :param pulumi.Input[_builtins.int] slow_op_threshold_ms: Operations that run for longer than this threshold are considered slow which are then recorded to the diagnostic logs. Higher log levels (verbosity) will record all operations regardless of this threshold on the primary node. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/configuration-options/#mongodb-setting-operationProfiling.slowOpThresholdMs).
        :param pulumi.Input[_builtins.int] transaction_lifetime_limit_seconds: Specifies the lifetime of multi-document transactions. Transactions that exceed this limit are considered expired and will be aborted by a periodic cleanup process. The cleanup process runs every `transactionLifetimeLimitSeconds/2 seconds` or at least once every 60 seconds. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/parameters/#mongodb-parameter-param.transactionLifetimeLimitSeconds).
        :param pulumi.Input[_builtins.int] verbosity: The log message verbosity level. The verbosity level determines the amount of Informational and Debug messages MongoDB outputs. 0 includes informational messages while 1...5 increases the level to include debug messages. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/configuration-options/#mongodb-setting-systemLog.verbosity).
        """
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if default_read_concern is not None:
            pulumi.set(__self__, "default_read_concern", default_read_concern)
        if default_write_concern is not None:
            pulumi.set(__self__, "default_write_concern", default_write_concern)
        if slow_op_threshold_ms is not None:
            pulumi.set(__self__, "slow_op_threshold_ms", slow_op_threshold_ms)
        if transaction_lifetime_limit_seconds is not None:
            pulumi.set(__self__, "transaction_lifetime_limit_seconds", transaction_lifetime_limit_seconds)
        if verbosity is not None:
            pulumi.set(__self__, "verbosity", verbosity)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the target MongoDB cluster.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter(name="defaultReadConcern")
    def default_read_concern(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the default consistency behavior of reads from the database. Data that is returned from the query with may or may not have been acknowledged by all nodes in the replicaset depending on this value. Learn more [here](https://www.mongodb.com/docs/manual/reference/read-concern/).
        """
        return pulumi.get(self, "default_read_concern")

    @default_read_concern.setter
    def default_read_concern(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_read_concern", value)

    @_builtins.property
    @pulumi.getter(name="defaultWriteConcern")
    def default_write_concern(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Describes the level of acknowledgment requested from MongoDB for write operations clusters. This field can set to either `majority` or a number`0...n` which will describe the number of nodes that must acknowledge the write operation before it is fully accepted. Setting to `0` will request no acknowledgement of the write operation. Learn more [here](https://www.mongodb.com/docs/manual/reference/write-concern/).
        """
        return pulumi.get(self, "default_write_concern")

    @default_write_concern.setter
    def default_write_concern(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_write_concern", value)

    @_builtins.property
    @pulumi.getter(name="slowOpThresholdMs")
    def slow_op_threshold_ms(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Operations that run for longer than this threshold are considered slow which are then recorded to the diagnostic logs. Higher log levels (verbosity) will record all operations regardless of this threshold on the primary node. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/configuration-options/#mongodb-setting-operationProfiling.slowOpThresholdMs).
        """
        return pulumi.get(self, "slow_op_threshold_ms")

    @slow_op_threshold_ms.setter
    def slow_op_threshold_ms(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "slow_op_threshold_ms", value)

    @_builtins.property
    @pulumi.getter(name="transactionLifetimeLimitSeconds")
    def transaction_lifetime_limit_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the lifetime of multi-document transactions. Transactions that exceed this limit are considered expired and will be aborted by a periodic cleanup process. The cleanup process runs every `transactionLifetimeLimitSeconds/2 seconds` or at least once every 60 seconds. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/parameters/#mongodb-parameter-param.transactionLifetimeLimitSeconds).
        """
        return pulumi.get(self, "transaction_lifetime_limit_seconds")

    @transaction_lifetime_limit_seconds.setter
    def transaction_lifetime_limit_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "transaction_lifetime_limit_seconds", value)

    @_builtins.property
    @pulumi.getter
    def verbosity(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The log message verbosity level. The verbosity level determines the amount of Informational and Debug messages MongoDB outputs. 0 includes informational messages while 1...5 increases the level to include debug messages. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/configuration-options/#mongodb-setting-systemLog.verbosity).
        """
        return pulumi.get(self, "verbosity")

    @verbosity.setter
    def verbosity(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "verbosity", value)


@pulumi.type_token("digitalocean:index/databaseMongodbConfig:DatabaseMongodbConfig")
class DatabaseMongodbConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 default_read_concern: Optional[pulumi.Input[_builtins.str]] = None,
                 default_write_concern: Optional[pulumi.Input[_builtins.str]] = None,
                 slow_op_threshold_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 transaction_lifetime_limit_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 verbosity: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        Provides a virtual resource that can be used to change advanced configuration
        options for a DigitalOcean managed MongoDB database cluster.

        > **Note** MongoDB configurations are only removed from state when destroyed. The remote configuration is not unset.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        example_database_cluster = digitalocean.DatabaseCluster("example",
            name="example-mongodb-cluster",
            engine="mongodb",
            version="7",
            size=digitalocean.DatabaseSlug.D_B_1_VPCU1_GB,
            region=digitalocean.Region.NYC3,
            node_count=1)
        example = digitalocean.DatabaseMongodbConfig("example",
            cluster_id=example_database_cluster.id,
            default_read_concern="majority",
            default_write_concern="majority",
            transaction_lifetime_limit_seconds=100,
            slow_op_threshold_ms=100,
            verbosity=3)
        ```

        ## Import

        A MongoDB database cluster's configuration can be imported using the `id` the parent cluster, e.g.

        ```sh
        $ pulumi import digitalocean:index/databaseMongodbConfig:DatabaseMongodbConfig example 4b62829a-9c42-465b-aaa3-84051048e712
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the target MongoDB cluster.
        :param pulumi.Input[_builtins.str] default_read_concern: Specifies the default consistency behavior of reads from the database. Data that is returned from the query with may or may not have been acknowledged by all nodes in the replicaset depending on this value. Learn more [here](https://www.mongodb.com/docs/manual/reference/read-concern/).
        :param pulumi.Input[_builtins.str] default_write_concern: Describes the level of acknowledgment requested from MongoDB for write operations clusters. This field can set to either `majority` or a number`0...n` which will describe the number of nodes that must acknowledge the write operation before it is fully accepted. Setting to `0` will request no acknowledgement of the write operation. Learn more [here](https://www.mongodb.com/docs/manual/reference/write-concern/).
        :param pulumi.Input[_builtins.int] slow_op_threshold_ms: Operations that run for longer than this threshold are considered slow which are then recorded to the diagnostic logs. Higher log levels (verbosity) will record all operations regardless of this threshold on the primary node. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/configuration-options/#mongodb-setting-operationProfiling.slowOpThresholdMs).
        :param pulumi.Input[_builtins.int] transaction_lifetime_limit_seconds: Specifies the lifetime of multi-document transactions. Transactions that exceed this limit are considered expired and will be aborted by a periodic cleanup process. The cleanup process runs every `transactionLifetimeLimitSeconds/2 seconds` or at least once every 60 seconds. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/parameters/#mongodb-parameter-param.transactionLifetimeLimitSeconds).
        :param pulumi.Input[_builtins.int] verbosity: The log message verbosity level. The verbosity level determines the amount of Informational and Debug messages MongoDB outputs. 0 includes informational messages while 1...5 increases the level to include debug messages. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/configuration-options/#mongodb-setting-systemLog.verbosity).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DatabaseMongodbConfigArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a virtual resource that can be used to change advanced configuration
        options for a DigitalOcean managed MongoDB database cluster.

        > **Note** MongoDB configurations are only removed from state when destroyed. The remote configuration is not unset.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        example_database_cluster = digitalocean.DatabaseCluster("example",
            name="example-mongodb-cluster",
            engine="mongodb",
            version="7",
            size=digitalocean.DatabaseSlug.D_B_1_VPCU1_GB,
            region=digitalocean.Region.NYC3,
            node_count=1)
        example = digitalocean.DatabaseMongodbConfig("example",
            cluster_id=example_database_cluster.id,
            default_read_concern="majority",
            default_write_concern="majority",
            transaction_lifetime_limit_seconds=100,
            slow_op_threshold_ms=100,
            verbosity=3)
        ```

        ## Import

        A MongoDB database cluster's configuration can be imported using the `id` the parent cluster, e.g.

        ```sh
        $ pulumi import digitalocean:index/databaseMongodbConfig:DatabaseMongodbConfig example 4b62829a-9c42-465b-aaa3-84051048e712
        ```

        :param str resource_name: The name of the resource.
        :param DatabaseMongodbConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DatabaseMongodbConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 default_read_concern: Optional[pulumi.Input[_builtins.str]] = None,
                 default_write_concern: Optional[pulumi.Input[_builtins.str]] = None,
                 slow_op_threshold_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 transaction_lifetime_limit_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 verbosity: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DatabaseMongodbConfigArgs.__new__(DatabaseMongodbConfigArgs)

            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["default_read_concern"] = default_read_concern
            __props__.__dict__["default_write_concern"] = default_write_concern
            __props__.__dict__["slow_op_threshold_ms"] = slow_op_threshold_ms
            __props__.__dict__["transaction_lifetime_limit_seconds"] = transaction_lifetime_limit_seconds
            __props__.__dict__["verbosity"] = verbosity
        super(DatabaseMongodbConfig, __self__).__init__(
            'digitalocean:index/databaseMongodbConfig:DatabaseMongodbConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
            default_read_concern: Optional[pulumi.Input[_builtins.str]] = None,
            default_write_concern: Optional[pulumi.Input[_builtins.str]] = None,
            slow_op_threshold_ms: Optional[pulumi.Input[_builtins.int]] = None,
            transaction_lifetime_limit_seconds: Optional[pulumi.Input[_builtins.int]] = None,
            verbosity: Optional[pulumi.Input[_builtins.int]] = None) -> 'DatabaseMongodbConfig':
        """
        Get an existing DatabaseMongodbConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the target MongoDB cluster.
        :param pulumi.Input[_builtins.str] default_read_concern: Specifies the default consistency behavior of reads from the database. Data that is returned from the query with may or may not have been acknowledged by all nodes in the replicaset depending on this value. Learn more [here](https://www.mongodb.com/docs/manual/reference/read-concern/).
        :param pulumi.Input[_builtins.str] default_write_concern: Describes the level of acknowledgment requested from MongoDB for write operations clusters. This field can set to either `majority` or a number`0...n` which will describe the number of nodes that must acknowledge the write operation before it is fully accepted. Setting to `0` will request no acknowledgement of the write operation. Learn more [here](https://www.mongodb.com/docs/manual/reference/write-concern/).
        :param pulumi.Input[_builtins.int] slow_op_threshold_ms: Operations that run for longer than this threshold are considered slow which are then recorded to the diagnostic logs. Higher log levels (verbosity) will record all operations regardless of this threshold on the primary node. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/configuration-options/#mongodb-setting-operationProfiling.slowOpThresholdMs).
        :param pulumi.Input[_builtins.int] transaction_lifetime_limit_seconds: Specifies the lifetime of multi-document transactions. Transactions that exceed this limit are considered expired and will be aborted by a periodic cleanup process. The cleanup process runs every `transactionLifetimeLimitSeconds/2 seconds` or at least once every 60 seconds. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/parameters/#mongodb-parameter-param.transactionLifetimeLimitSeconds).
        :param pulumi.Input[_builtins.int] verbosity: The log message verbosity level. The verbosity level determines the amount of Informational and Debug messages MongoDB outputs. 0 includes informational messages while 1...5 increases the level to include debug messages. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/configuration-options/#mongodb-setting-systemLog.verbosity).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DatabaseMongodbConfigState.__new__(_DatabaseMongodbConfigState)

        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["default_read_concern"] = default_read_concern
        __props__.__dict__["default_write_concern"] = default_write_concern
        __props__.__dict__["slow_op_threshold_ms"] = slow_op_threshold_ms
        __props__.__dict__["transaction_lifetime_limit_seconds"] = transaction_lifetime_limit_seconds
        __props__.__dict__["verbosity"] = verbosity
        return DatabaseMongodbConfig(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the target MongoDB cluster.
        """
        return pulumi.get(self, "cluster_id")

    @_builtins.property
    @pulumi.getter(name="defaultReadConcern")
    def default_read_concern(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the default consistency behavior of reads from the database. Data that is returned from the query with may or may not have been acknowledged by all nodes in the replicaset depending on this value. Learn more [here](https://www.mongodb.com/docs/manual/reference/read-concern/).
        """
        return pulumi.get(self, "default_read_concern")

    @_builtins.property
    @pulumi.getter(name="defaultWriteConcern")
    def default_write_concern(self) -> pulumi.Output[_builtins.str]:
        """
        Describes the level of acknowledgment requested from MongoDB for write operations clusters. This field can set to either `majority` or a number`0...n` which will describe the number of nodes that must acknowledge the write operation before it is fully accepted. Setting to `0` will request no acknowledgement of the write operation. Learn more [here](https://www.mongodb.com/docs/manual/reference/write-concern/).
        """
        return pulumi.get(self, "default_write_concern")

    @_builtins.property
    @pulumi.getter(name="slowOpThresholdMs")
    def slow_op_threshold_ms(self) -> pulumi.Output[_builtins.int]:
        """
        Operations that run for longer than this threshold are considered slow which are then recorded to the diagnostic logs. Higher log levels (verbosity) will record all operations regardless of this threshold on the primary node. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/configuration-options/#mongodb-setting-operationProfiling.slowOpThresholdMs).
        """
        return pulumi.get(self, "slow_op_threshold_ms")

    @_builtins.property
    @pulumi.getter(name="transactionLifetimeLimitSeconds")
    def transaction_lifetime_limit_seconds(self) -> pulumi.Output[_builtins.int]:
        """
        Specifies the lifetime of multi-document transactions. Transactions that exceed this limit are considered expired and will be aborted by a periodic cleanup process. The cleanup process runs every `transactionLifetimeLimitSeconds/2 seconds` or at least once every 60 seconds. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/parameters/#mongodb-parameter-param.transactionLifetimeLimitSeconds).
        """
        return pulumi.get(self, "transaction_lifetime_limit_seconds")

    @_builtins.property
    @pulumi.getter
    def verbosity(self) -> pulumi.Output[_builtins.int]:
        """
        The log message verbosity level. The verbosity level determines the amount of Informational and Debug messages MongoDB outputs. 0 includes informational messages while 1...5 increases the level to include debug messages. <em>Changing this parameter will lead to a restart of the MongoDB service.</em> Learn more [here](https://www.mongodb.com/docs/manual/reference/configuration-options/#mongodb-setting-systemLog.verbosity).
        """
        return pulumi.get(self, "verbosity")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetRegionsResult',
    'AwaitableGetRegionsResult',
    'get_regions',
    'get_regions_output',
]

@pulumi.output_type
class GetRegionsResult:
    """
    A collection of values returned by getRegions.
    """
    def __init__(__self__, filters=None, id=None, regions=None, sorts=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)
        if sorts and not isinstance(sorts, list):
            raise TypeError("Expected argument 'sorts' to be a list")
        pulumi.set(__self__, "sorts", sorts)

    @_builtins.property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetRegionsFilterResult']]:
        return pulumi.get(self, "filters")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def regions(self) -> Sequence['outputs.GetRegionsRegionResult']:
        """
        A set of regions satisfying any `filter` and `sort` criteria. Each region has the following attributes:
        """
        return pulumi.get(self, "regions")

    @_builtins.property
    @pulumi.getter
    def sorts(self) -> Optional[Sequence['outputs.GetRegionsSortResult']]:
        return pulumi.get(self, "sorts")


class AwaitableGetRegionsResult(GetRegionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRegionsResult(
            filters=self.filters,
            id=self.id,
            regions=self.regions,
            sorts=self.sorts)


def get_regions(filters: Optional[Sequence[Union['GetRegionsFilterArgs', 'GetRegionsFilterArgsDict']]] = None,
                sorts: Optional[Sequence[Union['GetRegionsSortArgs', 'GetRegionsSortArgsDict']]] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRegionsResult:
    """
    Retrieve information about all supported DigitalOcean regions, with the ability to
    filter and sort the results. If no filters are specified, all regions will be returned.

    Note: You can use the `get_region` data source
    to obtain metadata about a single region if you already know the `slug` to retrieve.

    ## Example Usage

    Use the `filter` block with a `key` string and `values` list to filter regions.

    For example to find all available regions:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    available = digitalocean.get_regions(filters=[{
        "key": "available",
        "values": ["true"],
    }])
    ```

    You can filter on multiple fields and sort the results as well:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    available = digitalocean.get_regions(filters=[
            {
                "key": "available",
                "values": ["true"],
            },
            {
                "key": "features",
                "values": ["private_networking"],
            },
        ],
        sorts=[{
            "key": "name",
            "direction": "desc",
        }])
    ```


    :param Sequence[Union['GetRegionsFilterArgs', 'GetRegionsFilterArgsDict']] filters: Filter the results.
           The `filter` block is documented below.
    :param Sequence[Union['GetRegionsSortArgs', 'GetRegionsSortArgsDict']] sorts: Sort the results.
           The `sort` block is documented below.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['sorts'] = sorts
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('digitalocean:index/getRegions:getRegions', __args__, opts=opts, typ=GetRegionsResult).value

    return AwaitableGetRegionsResult(
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        regions=pulumi.get(__ret__, 'regions'),
        sorts=pulumi.get(__ret__, 'sorts'))
def get_regions_output(filters: Optional[pulumi.Input[Optional[Sequence[Union['GetRegionsFilterArgs', 'GetRegionsFilterArgsDict']]]]] = None,
                       sorts: Optional[pulumi.Input[Optional[Sequence[Union['GetRegionsSortArgs', 'GetRegionsSortArgsDict']]]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRegionsResult]:
    """
    Retrieve information about all supported DigitalOcean regions, with the ability to
    filter and sort the results. If no filters are specified, all regions will be returned.

    Note: You can use the `get_region` data source
    to obtain metadata about a single region if you already know the `slug` to retrieve.

    ## Example Usage

    Use the `filter` block with a `key` string and `values` list to filter regions.

    For example to find all available regions:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    available = digitalocean.get_regions(filters=[{
        "key": "available",
        "values": ["true"],
    }])
    ```

    You can filter on multiple fields and sort the results as well:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    available = digitalocean.get_regions(filters=[
            {
                "key": "available",
                "values": ["true"],
            },
            {
                "key": "features",
                "values": ["private_networking"],
            },
        ],
        sorts=[{
            "key": "name",
            "direction": "desc",
        }])
    ```


    :param Sequence[Union['GetRegionsFilterArgs', 'GetRegionsFilterArgsDict']] filters: Filter the results.
           The `filter` block is documented below.
    :param Sequence[Union['GetRegionsSortArgs', 'GetRegionsSortArgsDict']] sorts: Sort the results.
           The `sort` block is documented below.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['sorts'] = sorts
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('digitalocean:index/getRegions:getRegions', __args__, opts=opts, typ=GetRegionsResult)
    return __ret__.apply(lambda __response__: GetRegionsResult(
        filters=pulumi.get(__response__, 'filters'),
        id=pulumi.get(__response__, 'id'),
        regions=pulumi.get(__response__, 'regions'),
        sorts=pulumi.get(__response__, 'sorts')))
